"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6643 import (
        AbstractAssemblyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6644 import (
        AbstractShaftDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6645 import (
        AbstractShaftOrHousingDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6646 import (
        AbstractShaftToMountableComponentConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6647 import (
        AGMAGleasonConicalGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6648 import (
        AGMAGleasonConicalGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6649 import (
        AGMAGleasonConicalGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6650 import (
        AssemblyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6651 import (
        BearingDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6652 import (
        BeltConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6653 import (
        BeltDriveDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6654 import (
        BevelDifferentialGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6655 import (
        BevelDifferentialGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6656 import (
        BevelDifferentialGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6657 import (
        BevelDifferentialPlanetGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6658 import (
        BevelDifferentialSunGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6659 import (
        BevelGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6660 import (
        BevelGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6661 import (
        BevelGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6662 import (
        BoltDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6663 import (
        BoltedJointDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6664 import (
        ClutchConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6665 import (
        ClutchDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6666 import (
        ClutchHalfDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6667 import (
        CoaxialConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6668 import (
        ComponentDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6669 import (
        ConceptCouplingConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6670 import (
        ConceptCouplingDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6671 import (
        ConceptCouplingHalfDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6672 import (
        ConceptGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6673 import (
        ConceptGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6674 import (
        ConceptGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6675 import (
        ConicalGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6676 import (
        ConicalGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6677 import (
        ConicalGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6678 import (
        ConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6679 import (
        ConnectorDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6680 import (
        CouplingConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6681 import (
        CouplingDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6682 import (
        CouplingHalfDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6683 import (
        CVTBeltConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6684 import (
        CVTDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6685 import (
        CVTPulleyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6686 import (
        CycloidalAssemblyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6687 import (
        CycloidalDiscCentralBearingConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6688 import (
        CycloidalDiscDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6689 import (
        CycloidalDiscPlanetaryBearingConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6690 import (
        CylindricalGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6691 import (
        CylindricalGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6692 import (
        CylindricalGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6693 import (
        CylindricalPlanetGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6694 import (
        DatumDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6695 import (
        DynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6696 import (
        DynamicAnalysisDrawStyle,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6697 import (
        ExternalCADModelDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6698 import (
        FaceGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6699 import (
        FaceGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6700 import (
        FaceGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6701 import (
        FEPartDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6702 import (
        FlexiblePinAssemblyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6703 import (
        GearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6704 import (
        GearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6705 import (
        GearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6706 import (
        GuideDxfModelDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6707 import (
        HypoidGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6708 import (
        HypoidGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6709 import (
        HypoidGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6710 import (
        InterMountableComponentConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6711 import (
        KlingelnbergCycloPalloidConicalGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6712 import (
        KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6713 import (
        KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6714 import (
        KlingelnbergCycloPalloidHypoidGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6715 import (
        KlingelnbergCycloPalloidHypoidGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6716 import (
        KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6717 import (
        KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6718 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6719 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6720 import (
        MassDiscDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6721 import (
        MeasurementComponentDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6722 import (
        MicrophoneArrayDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6723 import (
        MicrophoneDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6724 import (
        MountableComponentDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6725 import (
        OilSealDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6726 import (
        PartDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6727 import (
        PartToPartShearCouplingConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6728 import (
        PartToPartShearCouplingDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6729 import (
        PartToPartShearCouplingHalfDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6730 import (
        PlanetaryConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6731 import (
        PlanetaryGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6732 import (
        PlanetCarrierDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6733 import (
        PointLoadDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6734 import (
        PowerLoadDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6735 import (
        PulleyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6736 import (
        RingPinsDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6737 import (
        RingPinsToDiscConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6738 import (
        RollingRingAssemblyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6739 import (
        RollingRingConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6740 import (
        RollingRingDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6741 import (
        RootAssemblyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6742 import (
        ShaftDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6743 import (
        ShaftHubConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6744 import (
        ShaftToMountableComponentConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6745 import (
        SpecialisedAssemblyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6746 import (
        SpiralBevelGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6747 import (
        SpiralBevelGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6748 import (
        SpiralBevelGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6749 import (
        SpringDamperConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6750 import (
        SpringDamperDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6751 import (
        SpringDamperHalfDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6752 import (
        StraightBevelDiffGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6753 import (
        StraightBevelDiffGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6754 import (
        StraightBevelDiffGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6755 import (
        StraightBevelGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6756 import (
        StraightBevelGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6757 import (
        StraightBevelGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6758 import (
        StraightBevelPlanetGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6759 import (
        StraightBevelSunGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6760 import (
        SynchroniserDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6761 import (
        SynchroniserHalfDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6762 import (
        SynchroniserPartDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6763 import (
        SynchroniserSleeveDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6764 import (
        TorqueConverterConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6765 import (
        TorqueConverterDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6766 import (
        TorqueConverterPumpDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6767 import (
        TorqueConverterTurbineDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6768 import (
        UnbalancedMassDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6769 import (
        VirtualComponentDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6770 import (
        WormGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6771 import (
        WormGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6772 import (
        WormGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6773 import (
        ZerolBevelGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6774 import (
        ZerolBevelGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6775 import (
        ZerolBevelGearSetDynamicAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.dynamic_analyses._6643": [
            "AbstractAssemblyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6644": [
            "AbstractShaftDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6645": [
            "AbstractShaftOrHousingDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6646": [
            "AbstractShaftToMountableComponentConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6647": [
            "AGMAGleasonConicalGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6648": [
            "AGMAGleasonConicalGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6649": [
            "AGMAGleasonConicalGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6650": [
            "AssemblyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6651": [
            "BearingDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6652": [
            "BeltConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6653": [
            "BeltDriveDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6654": [
            "BevelDifferentialGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6655": [
            "BevelDifferentialGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6656": [
            "BevelDifferentialGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6657": [
            "BevelDifferentialPlanetGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6658": [
            "BevelDifferentialSunGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6659": [
            "BevelGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6660": [
            "BevelGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6661": [
            "BevelGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6662": [
            "BoltDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6663": [
            "BoltedJointDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6664": [
            "ClutchConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6665": [
            "ClutchDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6666": [
            "ClutchHalfDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6667": [
            "CoaxialConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6668": [
            "ComponentDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6669": [
            "ConceptCouplingConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6670": [
            "ConceptCouplingDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6671": [
            "ConceptCouplingHalfDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6672": [
            "ConceptGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6673": [
            "ConceptGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6674": [
            "ConceptGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6675": [
            "ConicalGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6676": [
            "ConicalGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6677": [
            "ConicalGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6678": [
            "ConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6679": [
            "ConnectorDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6680": [
            "CouplingConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6681": [
            "CouplingDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6682": [
            "CouplingHalfDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6683": [
            "CVTBeltConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6684": [
            "CVTDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6685": [
            "CVTPulleyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6686": [
            "CycloidalAssemblyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6687": [
            "CycloidalDiscCentralBearingConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6688": [
            "CycloidalDiscDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6689": [
            "CycloidalDiscPlanetaryBearingConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6690": [
            "CylindricalGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6691": [
            "CylindricalGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6692": [
            "CylindricalGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6693": [
            "CylindricalPlanetGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6694": [
            "DatumDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6695": [
            "DynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6696": [
            "DynamicAnalysisDrawStyle"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6697": [
            "ExternalCADModelDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6698": [
            "FaceGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6699": [
            "FaceGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6700": [
            "FaceGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6701": [
            "FEPartDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6702": [
            "FlexiblePinAssemblyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6703": [
            "GearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6704": [
            "GearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6705": [
            "GearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6706": [
            "GuideDxfModelDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6707": [
            "HypoidGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6708": [
            "HypoidGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6709": [
            "HypoidGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6710": [
            "InterMountableComponentConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6711": [
            "KlingelnbergCycloPalloidConicalGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6712": [
            "KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6713": [
            "KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6714": [
            "KlingelnbergCycloPalloidHypoidGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6715": [
            "KlingelnbergCycloPalloidHypoidGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6716": [
            "KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6717": [
            "KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6718": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6719": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6720": [
            "MassDiscDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6721": [
            "MeasurementComponentDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6722": [
            "MicrophoneArrayDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6723": [
            "MicrophoneDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6724": [
            "MountableComponentDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6725": [
            "OilSealDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6726": [
            "PartDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6727": [
            "PartToPartShearCouplingConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6728": [
            "PartToPartShearCouplingDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6729": [
            "PartToPartShearCouplingHalfDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6730": [
            "PlanetaryConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6731": [
            "PlanetaryGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6732": [
            "PlanetCarrierDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6733": [
            "PointLoadDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6734": [
            "PowerLoadDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6735": [
            "PulleyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6736": [
            "RingPinsDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6737": [
            "RingPinsToDiscConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6738": [
            "RollingRingAssemblyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6739": [
            "RollingRingConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6740": [
            "RollingRingDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6741": [
            "RootAssemblyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6742": [
            "ShaftDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6743": [
            "ShaftHubConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6744": [
            "ShaftToMountableComponentConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6745": [
            "SpecialisedAssemblyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6746": [
            "SpiralBevelGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6747": [
            "SpiralBevelGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6748": [
            "SpiralBevelGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6749": [
            "SpringDamperConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6750": [
            "SpringDamperDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6751": [
            "SpringDamperHalfDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6752": [
            "StraightBevelDiffGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6753": [
            "StraightBevelDiffGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6754": [
            "StraightBevelDiffGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6755": [
            "StraightBevelGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6756": [
            "StraightBevelGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6757": [
            "StraightBevelGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6758": [
            "StraightBevelPlanetGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6759": [
            "StraightBevelSunGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6760": [
            "SynchroniserDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6761": [
            "SynchroniserHalfDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6762": [
            "SynchroniserPartDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6763": [
            "SynchroniserSleeveDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6764": [
            "TorqueConverterConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6765": [
            "TorqueConverterDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6766": [
            "TorqueConverterPumpDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6767": [
            "TorqueConverterTurbineDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6768": [
            "UnbalancedMassDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6769": [
            "VirtualComponentDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6770": [
            "WormGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6771": [
            "WormGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6772": [
            "WormGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6773": [
            "ZerolBevelGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6774": [
            "ZerolBevelGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6775": [
            "ZerolBevelGearSetDynamicAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyDynamicAnalysis",
    "AbstractShaftDynamicAnalysis",
    "AbstractShaftOrHousingDynamicAnalysis",
    "AbstractShaftToMountableComponentConnectionDynamicAnalysis",
    "AGMAGleasonConicalGearDynamicAnalysis",
    "AGMAGleasonConicalGearMeshDynamicAnalysis",
    "AGMAGleasonConicalGearSetDynamicAnalysis",
    "AssemblyDynamicAnalysis",
    "BearingDynamicAnalysis",
    "BeltConnectionDynamicAnalysis",
    "BeltDriveDynamicAnalysis",
    "BevelDifferentialGearDynamicAnalysis",
    "BevelDifferentialGearMeshDynamicAnalysis",
    "BevelDifferentialGearSetDynamicAnalysis",
    "BevelDifferentialPlanetGearDynamicAnalysis",
    "BevelDifferentialSunGearDynamicAnalysis",
    "BevelGearDynamicAnalysis",
    "BevelGearMeshDynamicAnalysis",
    "BevelGearSetDynamicAnalysis",
    "BoltDynamicAnalysis",
    "BoltedJointDynamicAnalysis",
    "ClutchConnectionDynamicAnalysis",
    "ClutchDynamicAnalysis",
    "ClutchHalfDynamicAnalysis",
    "CoaxialConnectionDynamicAnalysis",
    "ComponentDynamicAnalysis",
    "ConceptCouplingConnectionDynamicAnalysis",
    "ConceptCouplingDynamicAnalysis",
    "ConceptCouplingHalfDynamicAnalysis",
    "ConceptGearDynamicAnalysis",
    "ConceptGearMeshDynamicAnalysis",
    "ConceptGearSetDynamicAnalysis",
    "ConicalGearDynamicAnalysis",
    "ConicalGearMeshDynamicAnalysis",
    "ConicalGearSetDynamicAnalysis",
    "ConnectionDynamicAnalysis",
    "ConnectorDynamicAnalysis",
    "CouplingConnectionDynamicAnalysis",
    "CouplingDynamicAnalysis",
    "CouplingHalfDynamicAnalysis",
    "CVTBeltConnectionDynamicAnalysis",
    "CVTDynamicAnalysis",
    "CVTPulleyDynamicAnalysis",
    "CycloidalAssemblyDynamicAnalysis",
    "CycloidalDiscCentralBearingConnectionDynamicAnalysis",
    "CycloidalDiscDynamicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionDynamicAnalysis",
    "CylindricalGearDynamicAnalysis",
    "CylindricalGearMeshDynamicAnalysis",
    "CylindricalGearSetDynamicAnalysis",
    "CylindricalPlanetGearDynamicAnalysis",
    "DatumDynamicAnalysis",
    "DynamicAnalysis",
    "DynamicAnalysisDrawStyle",
    "ExternalCADModelDynamicAnalysis",
    "FaceGearDynamicAnalysis",
    "FaceGearMeshDynamicAnalysis",
    "FaceGearSetDynamicAnalysis",
    "FEPartDynamicAnalysis",
    "FlexiblePinAssemblyDynamicAnalysis",
    "GearDynamicAnalysis",
    "GearMeshDynamicAnalysis",
    "GearSetDynamicAnalysis",
    "GuideDxfModelDynamicAnalysis",
    "HypoidGearDynamicAnalysis",
    "HypoidGearMeshDynamicAnalysis",
    "HypoidGearSetDynamicAnalysis",
    "InterMountableComponentConnectionDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis",
    "MassDiscDynamicAnalysis",
    "MeasurementComponentDynamicAnalysis",
    "MicrophoneArrayDynamicAnalysis",
    "MicrophoneDynamicAnalysis",
    "MountableComponentDynamicAnalysis",
    "OilSealDynamicAnalysis",
    "PartDynamicAnalysis",
    "PartToPartShearCouplingConnectionDynamicAnalysis",
    "PartToPartShearCouplingDynamicAnalysis",
    "PartToPartShearCouplingHalfDynamicAnalysis",
    "PlanetaryConnectionDynamicAnalysis",
    "PlanetaryGearSetDynamicAnalysis",
    "PlanetCarrierDynamicAnalysis",
    "PointLoadDynamicAnalysis",
    "PowerLoadDynamicAnalysis",
    "PulleyDynamicAnalysis",
    "RingPinsDynamicAnalysis",
    "RingPinsToDiscConnectionDynamicAnalysis",
    "RollingRingAssemblyDynamicAnalysis",
    "RollingRingConnectionDynamicAnalysis",
    "RollingRingDynamicAnalysis",
    "RootAssemblyDynamicAnalysis",
    "ShaftDynamicAnalysis",
    "ShaftHubConnectionDynamicAnalysis",
    "ShaftToMountableComponentConnectionDynamicAnalysis",
    "SpecialisedAssemblyDynamicAnalysis",
    "SpiralBevelGearDynamicAnalysis",
    "SpiralBevelGearMeshDynamicAnalysis",
    "SpiralBevelGearSetDynamicAnalysis",
    "SpringDamperConnectionDynamicAnalysis",
    "SpringDamperDynamicAnalysis",
    "SpringDamperHalfDynamicAnalysis",
    "StraightBevelDiffGearDynamicAnalysis",
    "StraightBevelDiffGearMeshDynamicAnalysis",
    "StraightBevelDiffGearSetDynamicAnalysis",
    "StraightBevelGearDynamicAnalysis",
    "StraightBevelGearMeshDynamicAnalysis",
    "StraightBevelGearSetDynamicAnalysis",
    "StraightBevelPlanetGearDynamicAnalysis",
    "StraightBevelSunGearDynamicAnalysis",
    "SynchroniserDynamicAnalysis",
    "SynchroniserHalfDynamicAnalysis",
    "SynchroniserPartDynamicAnalysis",
    "SynchroniserSleeveDynamicAnalysis",
    "TorqueConverterConnectionDynamicAnalysis",
    "TorqueConverterDynamicAnalysis",
    "TorqueConverterPumpDynamicAnalysis",
    "TorqueConverterTurbineDynamicAnalysis",
    "UnbalancedMassDynamicAnalysis",
    "VirtualComponentDynamicAnalysis",
    "WormGearDynamicAnalysis",
    "WormGearMeshDynamicAnalysis",
    "WormGearSetDynamicAnalysis",
    "ZerolBevelGearDynamicAnalysis",
    "ZerolBevelGearMeshDynamicAnalysis",
    "ZerolBevelGearSetDynamicAnalysis",
)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6370 import (
        AbstractAssemblyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6371 import (
        AbstractShaftHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6372 import (
        AbstractShaftOrHousingHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6373 import (
        AbstractShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6374 import (
        AGMAGleasonConicalGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6375 import (
        AGMAGleasonConicalGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6376 import (
        AGMAGleasonConicalGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6377 import (
        AssemblyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6378 import (
        BearingHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6379 import (
        BeltConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6380 import (
        BeltDriveHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6381 import (
        BevelDifferentialGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6382 import (
        BevelDifferentialGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6383 import (
        BevelDifferentialGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6384 import (
        BevelDifferentialPlanetGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6385 import (
        BevelDifferentialSunGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6386 import (
        BevelGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6387 import (
        BevelGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6388 import (
        BevelGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6389 import (
        BoltedJointHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6390 import (
        BoltHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6391 import (
        ClutchConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6392 import (
        ClutchHalfHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6393 import (
        ClutchHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6394 import (
        CoaxialConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6395 import (
        ComponentHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6396 import (
        ConceptCouplingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6397 import (
        ConceptCouplingHalfHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6398 import (
        ConceptCouplingHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6399 import (
        ConceptGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6400 import (
        ConceptGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6401 import (
        ConceptGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6402 import (
        ConicalGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6403 import (
        ConicalGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6404 import (
        ConicalGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6405 import (
        ConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6406 import (
        ConnectorHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6407 import (
        CouplingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6408 import (
        CouplingHalfHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6409 import (
        CouplingHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6410 import (
        CVTBeltConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6411 import (
        CVTHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6412 import (
        CVTPulleyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6413 import (
        CycloidalAssemblyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6414 import (
        CycloidalDiscCentralBearingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6415 import (
        CycloidalDiscHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6416 import (
        CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6417 import (
        CylindricalGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6418 import (
        CylindricalGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6419 import (
        CylindricalGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6420 import (
        CylindricalPlanetGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6421 import (
        DatumHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6422 import (
        ExternalCADModelHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6423 import (
        FaceGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6424 import (
        FaceGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6425 import (
        FaceGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6426 import (
        FEPartHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6427 import (
        FlexiblePinAssemblyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6428 import (
        GearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6429 import (
        GearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6430 import (
        GearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6431 import (
        GuideDxfModelHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6432 import (
        HarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6433 import (
        HypoidGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6434 import (
        HypoidGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6435 import (
        HypoidGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6436 import (
        InterMountableComponentConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6437 import (
        KlingelnbergCycloPalloidConicalGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6438 import (
        KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6439 import (
        KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6440 import (
        KlingelnbergCycloPalloidHypoidGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6441 import (
        KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6442 import (
        KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6443 import (
        KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6444 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6445 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6446 import (
        MassDiscHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6447 import (
        MeasurementComponentHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6448 import (
        MicrophoneArrayHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6449 import (
        MicrophoneHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6450 import (
        ModalAnalysisForHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6451 import (
        MountableComponentHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6452 import (
        OilSealHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6453 import (
        PartHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6454 import (
        PartToPartShearCouplingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6455 import (
        PartToPartShearCouplingHalfHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6456 import (
        PartToPartShearCouplingHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6457 import (
        PlanetaryConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6458 import (
        PlanetaryGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6459 import (
        PlanetCarrierHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6460 import (
        PointLoadHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6461 import (
        PowerLoadHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6462 import (
        PulleyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6463 import (
        RingPinsHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6464 import (
        RingPinsToDiscConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6465 import (
        RollingRingAssemblyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6466 import (
        RollingRingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6467 import (
        RollingRingHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6468 import (
        RootAssemblyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6469 import (
        ShaftHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6470 import (
        ShaftHubConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6471 import (
        ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6472 import (
        SpecialisedAssemblyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6473 import (
        SpiralBevelGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6474 import (
        SpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6475 import (
        SpiralBevelGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6476 import (
        SpringDamperConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6477 import (
        SpringDamperHalfHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6478 import (
        SpringDamperHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6479 import (
        StraightBevelDiffGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6480 import (
        StraightBevelDiffGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6481 import (
        StraightBevelDiffGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6482 import (
        StraightBevelGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6483 import (
        StraightBevelGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6484 import (
        StraightBevelGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6485 import (
        StraightBevelPlanetGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6486 import (
        StraightBevelSunGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6487 import (
        SynchroniserHalfHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6488 import (
        SynchroniserHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6489 import (
        SynchroniserPartHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6490 import (
        SynchroniserSleeveHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6491 import (
        TorqueConverterConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6492 import (
        TorqueConverterHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6493 import (
        TorqueConverterPumpHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6494 import (
        TorqueConverterTurbineHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6495 import (
        UnbalancedMassHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6496 import (
        VirtualComponentHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6497 import (
        WormGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6498 import (
        WormGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6499 import (
        WormGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6500 import (
        ZerolBevelGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6501 import (
        ZerolBevelGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6502 import (
        ZerolBevelGearSetHarmonicAnalysisOfSingleExcitation,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6370": [
            "AbstractAssemblyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6371": [
            "AbstractShaftHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6372": [
            "AbstractShaftOrHousingHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6373": [
            "AbstractShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6374": [
            "AGMAGleasonConicalGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6375": [
            "AGMAGleasonConicalGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6376": [
            "AGMAGleasonConicalGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6377": [
            "AssemblyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6378": [
            "BearingHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6379": [
            "BeltConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6380": [
            "BeltDriveHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6381": [
            "BevelDifferentialGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6382": [
            "BevelDifferentialGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6383": [
            "BevelDifferentialGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6384": [
            "BevelDifferentialPlanetGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6385": [
            "BevelDifferentialSunGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6386": [
            "BevelGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6387": [
            "BevelGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6388": [
            "BevelGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6389": [
            "BoltedJointHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6390": [
            "BoltHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6391": [
            "ClutchConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6392": [
            "ClutchHalfHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6393": [
            "ClutchHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6394": [
            "CoaxialConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6395": [
            "ComponentHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6396": [
            "ConceptCouplingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6397": [
            "ConceptCouplingHalfHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6398": [
            "ConceptCouplingHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6399": [
            "ConceptGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6400": [
            "ConceptGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6401": [
            "ConceptGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6402": [
            "ConicalGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6403": [
            "ConicalGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6404": [
            "ConicalGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6405": [
            "ConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6406": [
            "ConnectorHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6407": [
            "CouplingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6408": [
            "CouplingHalfHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6409": [
            "CouplingHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6410": [
            "CVTBeltConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6411": [
            "CVTHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6412": [
            "CVTPulleyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6413": [
            "CycloidalAssemblyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6414": [
            "CycloidalDiscCentralBearingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6415": [
            "CycloidalDiscHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6416": [
            "CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6417": [
            "CylindricalGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6418": [
            "CylindricalGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6419": [
            "CylindricalGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6420": [
            "CylindricalPlanetGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6421": [
            "DatumHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6422": [
            "ExternalCADModelHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6423": [
            "FaceGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6424": [
            "FaceGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6425": [
            "FaceGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6426": [
            "FEPartHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6427": [
            "FlexiblePinAssemblyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6428": [
            "GearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6429": [
            "GearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6430": [
            "GearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6431": [
            "GuideDxfModelHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6432": [
            "HarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6433": [
            "HypoidGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6434": [
            "HypoidGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6435": [
            "HypoidGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6436": [
            "InterMountableComponentConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6437": [
            "KlingelnbergCycloPalloidConicalGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6438": [
            "KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6439": [
            "KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6440": [
            "KlingelnbergCycloPalloidHypoidGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6441": [
            "KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6442": [
            "KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6443": [
            "KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6444": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6445": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6446": [
            "MassDiscHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6447": [
            "MeasurementComponentHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6448": [
            "MicrophoneArrayHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6449": [
            "MicrophoneHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6450": [
            "ModalAnalysisForHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6451": [
            "MountableComponentHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6452": [
            "OilSealHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6453": [
            "PartHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6454": [
            "PartToPartShearCouplingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6455": [
            "PartToPartShearCouplingHalfHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6456": [
            "PartToPartShearCouplingHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6457": [
            "PlanetaryConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6458": [
            "PlanetaryGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6459": [
            "PlanetCarrierHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6460": [
            "PointLoadHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6461": [
            "PowerLoadHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6462": [
            "PulleyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6463": [
            "RingPinsHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6464": [
            "RingPinsToDiscConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6465": [
            "RollingRingAssemblyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6466": [
            "RollingRingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6467": [
            "RollingRingHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6468": [
            "RootAssemblyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6469": [
            "ShaftHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6470": [
            "ShaftHubConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6471": [
            "ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6472": [
            "SpecialisedAssemblyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6473": [
            "SpiralBevelGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6474": [
            "SpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6475": [
            "SpiralBevelGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6476": [
            "SpringDamperConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6477": [
            "SpringDamperHalfHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6478": [
            "SpringDamperHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6479": [
            "StraightBevelDiffGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6480": [
            "StraightBevelDiffGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6481": [
            "StraightBevelDiffGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6482": [
            "StraightBevelGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6483": [
            "StraightBevelGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6484": [
            "StraightBevelGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6485": [
            "StraightBevelPlanetGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6486": [
            "StraightBevelSunGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6487": [
            "SynchroniserHalfHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6488": [
            "SynchroniserHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6489": [
            "SynchroniserPartHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6490": [
            "SynchroniserSleeveHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6491": [
            "TorqueConverterConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6492": [
            "TorqueConverterHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6493": [
            "TorqueConverterPumpHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6494": [
            "TorqueConverterTurbineHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6495": [
            "UnbalancedMassHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6496": [
            "VirtualComponentHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6497": [
            "WormGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6498": [
            "WormGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6499": [
            "WormGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6500": [
            "ZerolBevelGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6501": [
            "ZerolBevelGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6502": [
            "ZerolBevelGearSetHarmonicAnalysisOfSingleExcitation"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyHarmonicAnalysisOfSingleExcitation",
    "AbstractShaftHarmonicAnalysisOfSingleExcitation",
    "AbstractShaftOrHousingHarmonicAnalysisOfSingleExcitation",
    "AbstractShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation",
    "AGMAGleasonConicalGearHarmonicAnalysisOfSingleExcitation",
    "AGMAGleasonConicalGearMeshHarmonicAnalysisOfSingleExcitation",
    "AGMAGleasonConicalGearSetHarmonicAnalysisOfSingleExcitation",
    "AssemblyHarmonicAnalysisOfSingleExcitation",
    "BearingHarmonicAnalysisOfSingleExcitation",
    "BeltConnectionHarmonicAnalysisOfSingleExcitation",
    "BeltDriveHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialGearHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialGearMeshHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialGearSetHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialPlanetGearHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialSunGearHarmonicAnalysisOfSingleExcitation",
    "BevelGearHarmonicAnalysisOfSingleExcitation",
    "BevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "BevelGearSetHarmonicAnalysisOfSingleExcitation",
    "BoltedJointHarmonicAnalysisOfSingleExcitation",
    "BoltHarmonicAnalysisOfSingleExcitation",
    "ClutchConnectionHarmonicAnalysisOfSingleExcitation",
    "ClutchHalfHarmonicAnalysisOfSingleExcitation",
    "ClutchHarmonicAnalysisOfSingleExcitation",
    "CoaxialConnectionHarmonicAnalysisOfSingleExcitation",
    "ComponentHarmonicAnalysisOfSingleExcitation",
    "ConceptCouplingConnectionHarmonicAnalysisOfSingleExcitation",
    "ConceptCouplingHalfHarmonicAnalysisOfSingleExcitation",
    "ConceptCouplingHarmonicAnalysisOfSingleExcitation",
    "ConceptGearHarmonicAnalysisOfSingleExcitation",
    "ConceptGearMeshHarmonicAnalysisOfSingleExcitation",
    "ConceptGearSetHarmonicAnalysisOfSingleExcitation",
    "ConicalGearHarmonicAnalysisOfSingleExcitation",
    "ConicalGearMeshHarmonicAnalysisOfSingleExcitation",
    "ConicalGearSetHarmonicAnalysisOfSingleExcitation",
    "ConnectionHarmonicAnalysisOfSingleExcitation",
    "ConnectorHarmonicAnalysisOfSingleExcitation",
    "CouplingConnectionHarmonicAnalysisOfSingleExcitation",
    "CouplingHalfHarmonicAnalysisOfSingleExcitation",
    "CouplingHarmonicAnalysisOfSingleExcitation",
    "CVTBeltConnectionHarmonicAnalysisOfSingleExcitation",
    "CVTHarmonicAnalysisOfSingleExcitation",
    "CVTPulleyHarmonicAnalysisOfSingleExcitation",
    "CycloidalAssemblyHarmonicAnalysisOfSingleExcitation",
    "CycloidalDiscCentralBearingConnectionHarmonicAnalysisOfSingleExcitation",
    "CycloidalDiscHarmonicAnalysisOfSingleExcitation",
    "CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysisOfSingleExcitation",
    "CylindricalGearHarmonicAnalysisOfSingleExcitation",
    "CylindricalGearMeshHarmonicAnalysisOfSingleExcitation",
    "CylindricalGearSetHarmonicAnalysisOfSingleExcitation",
    "CylindricalPlanetGearHarmonicAnalysisOfSingleExcitation",
    "DatumHarmonicAnalysisOfSingleExcitation",
    "ExternalCADModelHarmonicAnalysisOfSingleExcitation",
    "FaceGearHarmonicAnalysisOfSingleExcitation",
    "FaceGearMeshHarmonicAnalysisOfSingleExcitation",
    "FaceGearSetHarmonicAnalysisOfSingleExcitation",
    "FEPartHarmonicAnalysisOfSingleExcitation",
    "FlexiblePinAssemblyHarmonicAnalysisOfSingleExcitation",
    "GearHarmonicAnalysisOfSingleExcitation",
    "GearMeshHarmonicAnalysisOfSingleExcitation",
    "GearSetHarmonicAnalysisOfSingleExcitation",
    "GuideDxfModelHarmonicAnalysisOfSingleExcitation",
    "HarmonicAnalysisOfSingleExcitation",
    "HypoidGearHarmonicAnalysisOfSingleExcitation",
    "HypoidGearMeshHarmonicAnalysisOfSingleExcitation",
    "HypoidGearSetHarmonicAnalysisOfSingleExcitation",
    "InterMountableComponentConnectionHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidConicalGearHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidHypoidGearHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysisOfSingleExcitation",
    "MassDiscHarmonicAnalysisOfSingleExcitation",
    "MeasurementComponentHarmonicAnalysisOfSingleExcitation",
    "MicrophoneArrayHarmonicAnalysisOfSingleExcitation",
    "MicrophoneHarmonicAnalysisOfSingleExcitation",
    "ModalAnalysisForHarmonicAnalysis",
    "MountableComponentHarmonicAnalysisOfSingleExcitation",
    "OilSealHarmonicAnalysisOfSingleExcitation",
    "PartHarmonicAnalysisOfSingleExcitation",
    "PartToPartShearCouplingConnectionHarmonicAnalysisOfSingleExcitation",
    "PartToPartShearCouplingHalfHarmonicAnalysisOfSingleExcitation",
    "PartToPartShearCouplingHarmonicAnalysisOfSingleExcitation",
    "PlanetaryConnectionHarmonicAnalysisOfSingleExcitation",
    "PlanetaryGearSetHarmonicAnalysisOfSingleExcitation",
    "PlanetCarrierHarmonicAnalysisOfSingleExcitation",
    "PointLoadHarmonicAnalysisOfSingleExcitation",
    "PowerLoadHarmonicAnalysisOfSingleExcitation",
    "PulleyHarmonicAnalysisOfSingleExcitation",
    "RingPinsHarmonicAnalysisOfSingleExcitation",
    "RingPinsToDiscConnectionHarmonicAnalysisOfSingleExcitation",
    "RollingRingAssemblyHarmonicAnalysisOfSingleExcitation",
    "RollingRingConnectionHarmonicAnalysisOfSingleExcitation",
    "RollingRingHarmonicAnalysisOfSingleExcitation",
    "RootAssemblyHarmonicAnalysisOfSingleExcitation",
    "ShaftHarmonicAnalysisOfSingleExcitation",
    "ShaftHubConnectionHarmonicAnalysisOfSingleExcitation",
    "ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation",
    "SpecialisedAssemblyHarmonicAnalysisOfSingleExcitation",
    "SpiralBevelGearHarmonicAnalysisOfSingleExcitation",
    "SpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "SpiralBevelGearSetHarmonicAnalysisOfSingleExcitation",
    "SpringDamperConnectionHarmonicAnalysisOfSingleExcitation",
    "SpringDamperHalfHarmonicAnalysisOfSingleExcitation",
    "SpringDamperHarmonicAnalysisOfSingleExcitation",
    "StraightBevelDiffGearHarmonicAnalysisOfSingleExcitation",
    "StraightBevelDiffGearMeshHarmonicAnalysisOfSingleExcitation",
    "StraightBevelDiffGearSetHarmonicAnalysisOfSingleExcitation",
    "StraightBevelGearHarmonicAnalysisOfSingleExcitation",
    "StraightBevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "StraightBevelGearSetHarmonicAnalysisOfSingleExcitation",
    "StraightBevelPlanetGearHarmonicAnalysisOfSingleExcitation",
    "StraightBevelSunGearHarmonicAnalysisOfSingleExcitation",
    "SynchroniserHalfHarmonicAnalysisOfSingleExcitation",
    "SynchroniserHarmonicAnalysisOfSingleExcitation",
    "SynchroniserPartHarmonicAnalysisOfSingleExcitation",
    "SynchroniserSleeveHarmonicAnalysisOfSingleExcitation",
    "TorqueConverterConnectionHarmonicAnalysisOfSingleExcitation",
    "TorqueConverterHarmonicAnalysisOfSingleExcitation",
    "TorqueConverterPumpHarmonicAnalysisOfSingleExcitation",
    "TorqueConverterTurbineHarmonicAnalysisOfSingleExcitation",
    "UnbalancedMassHarmonicAnalysisOfSingleExcitation",
    "VirtualComponentHarmonicAnalysisOfSingleExcitation",
    "WormGearHarmonicAnalysisOfSingleExcitation",
    "WormGearMeshHarmonicAnalysisOfSingleExcitation",
    "WormGearSetHarmonicAnalysisOfSingleExcitation",
    "ZerolBevelGearHarmonicAnalysisOfSingleExcitation",
    "ZerolBevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "ZerolBevelGearSetHarmonicAnalysisOfSingleExcitation",
)



"""SteadyStateSynchronousResponseOnAShaft"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.analysis_cases import _7948

_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesOnAShaft",
    "SteadyStateSynchronousResponseOnAShaft",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2943
    from mastapy._private.system_model.analyses_and_results.analysis_cases import _7933
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
        _3391,
    )

    Self = TypeVar("Self", bound="SteadyStateSynchronousResponseOnAShaft")
    CastSelf = TypeVar(
        "CastSelf",
        bound="SteadyStateSynchronousResponseOnAShaft._Cast_SteadyStateSynchronousResponseOnAShaft",
    )


__docformat__ = "restructuredtext en"
__all__ = ("SteadyStateSynchronousResponseOnAShaft",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SteadyStateSynchronousResponseOnAShaft:
    """Special nested class for casting SteadyStateSynchronousResponseOnAShaft to subclasses."""

    __parent__: "SteadyStateSynchronousResponseOnAShaft"

    @property
    def static_load_analysis_case(self: "CastSelf") -> "_7948.StaticLoadAnalysisCase":
        return self.__parent__._cast(_7948.StaticLoadAnalysisCase)

    @property
    def analysis_case(self: "CastSelf") -> "_7933.AnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7933,
        )

        return self.__parent__._cast(_7933.AnalysisCase)

    @property
    def context(self: "CastSelf") -> "_2943.Context":
        from mastapy._private.system_model.analyses_and_results import _2943

        return self.__parent__._cast(_2943.Context)

    @property
    def steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "SteadyStateSynchronousResponseOnAShaft":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class SteadyStateSynchronousResponseOnAShaft(_7948.StaticLoadAnalysisCase):
    """SteadyStateSynchronousResponseOnAShaft

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def options(self: "Self") -> "_3391.SteadyStateSynchronousResponseOptions":
        """mastapy.system_model.analyses_and_results.steady_state_synchronous_responses.SteadyStateSynchronousResponseOptions

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Options")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_SteadyStateSynchronousResponseOnAShaft":
        """Cast to another type.

        Returns:
            _Cast_SteadyStateSynchronousResponseOnAShaft
        """
        return _Cast_SteadyStateSynchronousResponseOnAShaft(self)



"""ComponentStabilityAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.stability_analyses import _4156

_COMPONENT_STABILITY_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StabilityAnalyses",
    "ComponentStabilityAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7943,
        _7946,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses import (
        _4074,
        _4075,
        _4079,
        _4081,
        _4086,
        _4087,
        _4088,
        _4091,
        _4093,
        _4095,
        _4100,
        _4104,
        _4107,
        _4109,
        _4111,
        _4115,
        _4120,
        _4123,
        _4124,
        _4125,
        _4127,
        _4130,
        _4131,
        _4135,
        _4136,
        _4139,
        _4143,
        _4146,
        _4149,
        _4150,
        _4151,
        _4153,
        _4154,
        _4155,
        _4158,
        _4162,
        _4163,
        _4164,
        _4165,
        _4166,
        _4170,
        _4172,
        _4173,
        _4178,
        _4180,
        _4187,
        _4190,
        _4191,
        _4192,
        _4193,
        _4194,
        _4195,
        _4198,
        _4200,
        _4201,
        _4202,
        _4205,
        _4208,
    )
    from mastapy._private.system_model.part_model import _2715

    Self = TypeVar("Self", bound="ComponentStabilityAnalysis")
    CastSelf = TypeVar(
        "CastSelf", bound="ComponentStabilityAnalysis._Cast_ComponentStabilityAnalysis"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ComponentStabilityAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ComponentStabilityAnalysis:
    """Special nested class for casting ComponentStabilityAnalysis to subclasses."""

    __parent__: "ComponentStabilityAnalysis"

    @property
    def part_stability_analysis(self: "CastSelf") -> "_4156.PartStabilityAnalysis":
        return self.__parent__._cast(_4156.PartStabilityAnalysis)

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7946.PartStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7946,
        )

        return self.__parent__._cast(_7946.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7943.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7943,
        )

        return self.__parent__._cast(_7943.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def abstract_shaft_or_housing_stability_analysis(
        self: "CastSelf",
    ) -> "_4074.AbstractShaftOrHousingStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4074,
        )

        return self.__parent__._cast(_4074.AbstractShaftOrHousingStabilityAnalysis)

    @property
    def abstract_shaft_stability_analysis(
        self: "CastSelf",
    ) -> "_4075.AbstractShaftStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4075,
        )

        return self.__parent__._cast(_4075.AbstractShaftStabilityAnalysis)

    @property
    def agma_gleason_conical_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4079.AGMAGleasonConicalGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4079,
        )

        return self.__parent__._cast(_4079.AGMAGleasonConicalGearStabilityAnalysis)

    @property
    def bearing_stability_analysis(
        self: "CastSelf",
    ) -> "_4081.BearingStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4081,
        )

        return self.__parent__._cast(_4081.BearingStabilityAnalysis)

    @property
    def bevel_differential_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4086.BevelDifferentialGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4086,
        )

        return self.__parent__._cast(_4086.BevelDifferentialGearStabilityAnalysis)

    @property
    def bevel_differential_planet_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4087.BevelDifferentialPlanetGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4087,
        )

        return self.__parent__._cast(_4087.BevelDifferentialPlanetGearStabilityAnalysis)

    @property
    def bevel_differential_sun_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4088.BevelDifferentialSunGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4088,
        )

        return self.__parent__._cast(_4088.BevelDifferentialSunGearStabilityAnalysis)

    @property
    def bevel_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4091.BevelGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4091,
        )

        return self.__parent__._cast(_4091.BevelGearStabilityAnalysis)

    @property
    def bolt_stability_analysis(self: "CastSelf") -> "_4093.BoltStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4093,
        )

        return self.__parent__._cast(_4093.BoltStabilityAnalysis)

    @property
    def clutch_half_stability_analysis(
        self: "CastSelf",
    ) -> "_4095.ClutchHalfStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4095,
        )

        return self.__parent__._cast(_4095.ClutchHalfStabilityAnalysis)

    @property
    def concept_coupling_half_stability_analysis(
        self: "CastSelf",
    ) -> "_4100.ConceptCouplingHalfStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4100,
        )

        return self.__parent__._cast(_4100.ConceptCouplingHalfStabilityAnalysis)

    @property
    def concept_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4104.ConceptGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4104,
        )

        return self.__parent__._cast(_4104.ConceptGearStabilityAnalysis)

    @property
    def conical_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4107.ConicalGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4107,
        )

        return self.__parent__._cast(_4107.ConicalGearStabilityAnalysis)

    @property
    def connector_stability_analysis(
        self: "CastSelf",
    ) -> "_4109.ConnectorStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4109,
        )

        return self.__parent__._cast(_4109.ConnectorStabilityAnalysis)

    @property
    def coupling_half_stability_analysis(
        self: "CastSelf",
    ) -> "_4111.CouplingHalfStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4111,
        )

        return self.__parent__._cast(_4111.CouplingHalfStabilityAnalysis)

    @property
    def cvt_pulley_stability_analysis(
        self: "CastSelf",
    ) -> "_4115.CVTPulleyStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4115,
        )

        return self.__parent__._cast(_4115.CVTPulleyStabilityAnalysis)

    @property
    def cycloidal_disc_stability_analysis(
        self: "CastSelf",
    ) -> "_4120.CycloidalDiscStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4120,
        )

        return self.__parent__._cast(_4120.CycloidalDiscStabilityAnalysis)

    @property
    def cylindrical_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4123.CylindricalGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4123,
        )

        return self.__parent__._cast(_4123.CylindricalGearStabilityAnalysis)

    @property
    def cylindrical_planet_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4124.CylindricalPlanetGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4124,
        )

        return self.__parent__._cast(_4124.CylindricalPlanetGearStabilityAnalysis)

    @property
    def datum_stability_analysis(self: "CastSelf") -> "_4125.DatumStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4125,
        )

        return self.__parent__._cast(_4125.DatumStabilityAnalysis)

    @property
    def external_cad_model_stability_analysis(
        self: "CastSelf",
    ) -> "_4127.ExternalCADModelStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4127,
        )

        return self.__parent__._cast(_4127.ExternalCADModelStabilityAnalysis)

    @property
    def face_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4130.FaceGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4130,
        )

        return self.__parent__._cast(_4130.FaceGearStabilityAnalysis)

    @property
    def fe_part_stability_analysis(self: "CastSelf") -> "_4131.FEPartStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4131,
        )

        return self.__parent__._cast(_4131.FEPartStabilityAnalysis)

    @property
    def gear_stability_analysis(self: "CastSelf") -> "_4135.GearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4135,
        )

        return self.__parent__._cast(_4135.GearStabilityAnalysis)

    @property
    def guide_dxf_model_stability_analysis(
        self: "CastSelf",
    ) -> "_4136.GuideDxfModelStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4136,
        )

        return self.__parent__._cast(_4136.GuideDxfModelStabilityAnalysis)

    @property
    def hypoid_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4139.HypoidGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4139,
        )

        return self.__parent__._cast(_4139.HypoidGearStabilityAnalysis)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4143.KlingelnbergCycloPalloidConicalGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4143,
        )

        return self.__parent__._cast(
            _4143.KlingelnbergCycloPalloidConicalGearStabilityAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4146.KlingelnbergCycloPalloidHypoidGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4146,
        )

        return self.__parent__._cast(
            _4146.KlingelnbergCycloPalloidHypoidGearStabilityAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4149.KlingelnbergCycloPalloidSpiralBevelGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4149,
        )

        return self.__parent__._cast(
            _4149.KlingelnbergCycloPalloidSpiralBevelGearStabilityAnalysis
        )

    @property
    def mass_disc_stability_analysis(
        self: "CastSelf",
    ) -> "_4150.MassDiscStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4150,
        )

        return self.__parent__._cast(_4150.MassDiscStabilityAnalysis)

    @property
    def measurement_component_stability_analysis(
        self: "CastSelf",
    ) -> "_4151.MeasurementComponentStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4151,
        )

        return self.__parent__._cast(_4151.MeasurementComponentStabilityAnalysis)

    @property
    def microphone_stability_analysis(
        self: "CastSelf",
    ) -> "_4153.MicrophoneStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4153,
        )

        return self.__parent__._cast(_4153.MicrophoneStabilityAnalysis)

    @property
    def mountable_component_stability_analysis(
        self: "CastSelf",
    ) -> "_4154.MountableComponentStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4154,
        )

        return self.__parent__._cast(_4154.MountableComponentStabilityAnalysis)

    @property
    def oil_seal_stability_analysis(
        self: "CastSelf",
    ) -> "_4155.OilSealStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4155,
        )

        return self.__parent__._cast(_4155.OilSealStabilityAnalysis)

    @property
    def part_to_part_shear_coupling_half_stability_analysis(
        self: "CastSelf",
    ) -> "_4158.PartToPartShearCouplingHalfStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4158,
        )

        return self.__parent__._cast(_4158.PartToPartShearCouplingHalfStabilityAnalysis)

    @property
    def planet_carrier_stability_analysis(
        self: "CastSelf",
    ) -> "_4162.PlanetCarrierStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4162,
        )

        return self.__parent__._cast(_4162.PlanetCarrierStabilityAnalysis)

    @property
    def point_load_stability_analysis(
        self: "CastSelf",
    ) -> "_4163.PointLoadStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4163,
        )

        return self.__parent__._cast(_4163.PointLoadStabilityAnalysis)

    @property
    def power_load_stability_analysis(
        self: "CastSelf",
    ) -> "_4164.PowerLoadStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4164,
        )

        return self.__parent__._cast(_4164.PowerLoadStabilityAnalysis)

    @property
    def pulley_stability_analysis(self: "CastSelf") -> "_4165.PulleyStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4165,
        )

        return self.__parent__._cast(_4165.PulleyStabilityAnalysis)

    @property
    def ring_pins_stability_analysis(
        self: "CastSelf",
    ) -> "_4166.RingPinsStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4166,
        )

        return self.__parent__._cast(_4166.RingPinsStabilityAnalysis)

    @property
    def rolling_ring_stability_analysis(
        self: "CastSelf",
    ) -> "_4170.RollingRingStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4170,
        )

        return self.__parent__._cast(_4170.RollingRingStabilityAnalysis)

    @property
    def shaft_hub_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4172.ShaftHubConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4172,
        )

        return self.__parent__._cast(_4172.ShaftHubConnectionStabilityAnalysis)

    @property
    def shaft_stability_analysis(self: "CastSelf") -> "_4173.ShaftStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4173,
        )

        return self.__parent__._cast(_4173.ShaftStabilityAnalysis)

    @property
    def spiral_bevel_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4178.SpiralBevelGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4178,
        )

        return self.__parent__._cast(_4178.SpiralBevelGearStabilityAnalysis)

    @property
    def spring_damper_half_stability_analysis(
        self: "CastSelf",
    ) -> "_4180.SpringDamperHalfStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4180,
        )

        return self.__parent__._cast(_4180.SpringDamperHalfStabilityAnalysis)

    @property
    def straight_bevel_diff_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4187.StraightBevelDiffGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4187,
        )

        return self.__parent__._cast(_4187.StraightBevelDiffGearStabilityAnalysis)

    @property
    def straight_bevel_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4190.StraightBevelGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4190,
        )

        return self.__parent__._cast(_4190.StraightBevelGearStabilityAnalysis)

    @property
    def straight_bevel_planet_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4191.StraightBevelPlanetGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4191,
        )

        return self.__parent__._cast(_4191.StraightBevelPlanetGearStabilityAnalysis)

    @property
    def straight_bevel_sun_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4192.StraightBevelSunGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4192,
        )

        return self.__parent__._cast(_4192.StraightBevelSunGearStabilityAnalysis)

    @property
    def synchroniser_half_stability_analysis(
        self: "CastSelf",
    ) -> "_4193.SynchroniserHalfStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4193,
        )

        return self.__parent__._cast(_4193.SynchroniserHalfStabilityAnalysis)

    @property
    def synchroniser_part_stability_analysis(
        self: "CastSelf",
    ) -> "_4194.SynchroniserPartStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4194,
        )

        return self.__parent__._cast(_4194.SynchroniserPartStabilityAnalysis)

    @property
    def synchroniser_sleeve_stability_analysis(
        self: "CastSelf",
    ) -> "_4195.SynchroniserSleeveStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4195,
        )

        return self.__parent__._cast(_4195.SynchroniserSleeveStabilityAnalysis)

    @property
    def torque_converter_pump_stability_analysis(
        self: "CastSelf",
    ) -> "_4198.TorqueConverterPumpStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4198,
        )

        return self.__parent__._cast(_4198.TorqueConverterPumpStabilityAnalysis)

    @property
    def torque_converter_turbine_stability_analysis(
        self: "CastSelf",
    ) -> "_4200.TorqueConverterTurbineStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4200,
        )

        return self.__parent__._cast(_4200.TorqueConverterTurbineStabilityAnalysis)

    @property
    def unbalanced_mass_stability_analysis(
        self: "CastSelf",
    ) -> "_4201.UnbalancedMassStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4201,
        )

        return self.__parent__._cast(_4201.UnbalancedMassStabilityAnalysis)

    @property
    def virtual_component_stability_analysis(
        self: "CastSelf",
    ) -> "_4202.VirtualComponentStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4202,
        )

        return self.__parent__._cast(_4202.VirtualComponentStabilityAnalysis)

    @property
    def worm_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4205.WormGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4205,
        )

        return self.__parent__._cast(_4205.WormGearStabilityAnalysis)

    @property
    def zerol_bevel_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_4208.ZerolBevelGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4208,
        )

        return self.__parent__._cast(_4208.ZerolBevelGearStabilityAnalysis)

    @property
    def component_stability_analysis(self: "CastSelf") -> "ComponentStabilityAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ComponentStabilityAnalysis(_4156.PartStabilityAnalysis):
    """ComponentStabilityAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _COMPONENT_STABILITY_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2715.Component":
        """mastapy.system_model.part_model.Component

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_ComponentStabilityAnalysis":
        """Cast to another type.

        Returns:
            _Cast_ComponentStabilityAnalysis
        """
        return _Cast_ComponentStabilityAnalysis(self)



"""WindTurbineBladeModeDetails"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _0
from mastapy._private._internal import utility

_WIND_TURBINE_BLADE_MODE_DETAILS = python_net_import(
    "SMT.MastaAPI.SystemModel.PartModel", "WindTurbineBladeModeDetails"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="WindTurbineBladeModeDetails")
    CastSelf = TypeVar(
        "CastSelf",
        bound="WindTurbineBladeModeDetails._Cast_WindTurbineBladeModeDetails",
    )


__docformat__ = "restructuredtext en"
__all__ = ("WindTurbineBladeModeDetails",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_WindTurbineBladeModeDetails:
    """Special nested class for casting WindTurbineBladeModeDetails to subclasses."""

    __parent__: "WindTurbineBladeModeDetails"

    @property
    def wind_turbine_blade_mode_details(
        self: "CastSelf",
    ) -> "WindTurbineBladeModeDetails":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class WindTurbineBladeModeDetails(_0.APIBase):
    """WindTurbineBladeModeDetails

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _WIND_TURBINE_BLADE_MODE_DETAILS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def first_mode_frequency(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "FirstModeFrequency")

        if temp is None:
            return 0.0

        return temp

    @first_mode_frequency.setter
    @exception_bridge
    @enforce_parameter_types
    def first_mode_frequency(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "FirstModeFrequency",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def include_mode(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "IncludeMode")

        if temp is None:
            return False

        return temp

    @include_mode.setter
    @exception_bridge
    @enforce_parameter_types
    def include_mode(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "IncludeMode", bool(value) if value is not None else False
        )

    @property
    @exception_bridge
    def inertia_of_centre(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "InertiaOfCentre")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def inertia_of_hub(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "InertiaOfHub")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def inertia_of_tip(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "InertiaOfTip")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def second_mode_frequency(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "SecondModeFrequency")

        if temp is None:
            return 0.0

        return temp

    @second_mode_frequency.setter
    @exception_bridge
    @enforce_parameter_types
    def second_mode_frequency(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "SecondModeFrequency",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def stiffness_centre_to_tip(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessCentreToTip")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_hub_to_centre(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessHubToCentre")

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_WindTurbineBladeModeDetails":
        """Cast to another type.

        Returns:
            _Cast_WindTurbineBladeModeDetails
        """
        return _Cast_WindTurbineBladeModeDetails(self)
